Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(838)

Unified Diff: third_party/WebKit/Source/core/layout/ScrollAnchor.h

Issue 1875943004: [DNS] Don't adjust the scroll position if the anchor element changes in size (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: nit Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | third_party/WebKit/Source/core/layout/ScrollAnchor.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/layout/ScrollAnchor.h
diff --git a/third_party/WebKit/Source/core/layout/ScrollAnchor.h b/third_party/WebKit/Source/core/layout/ScrollAnchor.h
index 510a7a463977654ef94943b200e1c44202dd8a92..75cb56a6a0df2c9e6afac65918336a39056cad84 100644
--- a/third_party/WebKit/Source/core/layout/ScrollAnchor.h
+++ b/third_party/WebKit/Source/core/layout/ScrollAnchor.h
@@ -85,8 +85,11 @@ private:
// Which corner of m_anchorObject's bounding box to anchor to.
Corner m_corner;
// Location of m_layoutObject relative to scroller at time of save().
LayoutPoint m_savedRelativeOffset;
+
+ // The size of the m_anchorObject at the time of save().
+ LayoutSize m_savedAnchorSize;
};
} // namespace blink
« no previous file with comments | « no previous file | third_party/WebKit/Source/core/layout/ScrollAnchor.cpp » ('j') | no next file with comments »
@@ -85,8 +85,11 @@ private:
// Which corner of m_anchorObject's bounding box to anchor to.
Corner m_corner;
- // Location of m_layoutObject relative to scroller at time of save().
+ // Location of m_anchorObject relative to scroller at time of save().
LayoutPoint m_savedRelativeOffset;

Powered by Google App Engine
This is Rietveld 408576698